<?php
/**
 * Billow Theme Customizer
 *
 * @package Billow
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function billow_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'billow_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'billow_customize_partial_blogdescription',
			)
		);
	}

	//macros, sanitizing functions, validation function, etc.
	require_once 'customizer.functions.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound

	require_once 'customizer.blog.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once 'customizer.footer.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once 'customizer.global.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once 'customizer.header.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once 'customizer.home.page.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once 'customizer.post.navigation.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once 'customizer.sidebar.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once 'customizer.socials.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once 'customizer.typography.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
}
add_action( 'customize_register', 'billow_customize_register' );

/**
 * Custom Toggle control
 * Check for WP_Customizer_Control existence before adding custom control because WP_Customize_Control
 * is loaded on customizer page only
 *
 * @see _wp_customize_include()
 */
if ( class_exists( 'WP_Customize_Control' ) ) {
	require_once( get_template_directory() . '/inc/customizer/custom-controls/custom-controls.php' ); // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once( get_template_directory() . '/inc/customizer/control-multiple-checkbox/control-multiple-checkbox.php' ); // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once( get_template_directory() . '/inc/customizer/control-css-number-with-units/class.customizer_css_number_with_units_control.php' ); // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once( get_template_directory() . '/inc/customizer/control-reset-customizer/class.control_reset_customizer.php' ); // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	require_once( get_template_directory() . '/inc/customizer/control-button-link/class.control_button_link.php' ); // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound

	//--sanitation functions
	require_once( get_template_directory() . '/inc/customizer.sanitizer_functions.php' ); // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
}

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function billow_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function billow_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function billow_customize_preview_js() {
	wp_enqueue_script( 'billow_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'billow_customize_preview_js' );

/**
 * Binds JS handlers for the control area
 */
function billow_customize_controls_js() {
	wp_enqueue_script( 'billow_customize_controls_js', trailingslashit( get_template_directory_uri() ) . 'js/custom-controls.js', array(), time(), true );
}
add_action( 'customize_controls_enqueue_scripts', 'billow_customize_controls_js' );

