<?php

global $billow_google_font_options;

$billow_google_font_options = apply_filters( 'billow_google_font_options', array(
	'billow_base_font',
	'billow_heading1_font',
	'billow_heading2_font',
	'billow_heading3_font',
	'billow_heading4_font',
	'billow_heading5_font',
	'billow_heading6_font',
	'billow_home_page_title_font',
	'billow_home_page_button_font',
	'site_title_font',
	'title_tagline_font',
	'billow_button_font',
	'billow_button_border_radius',
	'billow_single_post_title_font',
	'billow_single_post_meta_font',
	'billow_post_nav_font',
	'billow_copyright_font',
	'billow_sidebar_font'
) );

// Theme Style Green
function billow_theme_green_color( $default_color = '#65bc7b' ) {

	$default_color = apply_filters( 'billow_theme_style_green', $default_color );
	$color = billow_get_theme_mod_hex_color( 'billow_theme_style_green', $default_color );

	return $color;
}

// Theme Style Violet
function billow_theme_lavender_color( $default_color = '#f4f5ff' ) {

	$default_color = apply_filters( 'billow_theme_style_lavender', $default_color );
	$color = billow_get_theme_mod_hex_color( 'billow_theme_style_lavender', $default_color );

	return $color;
}

function billow_theme_violet_color( $default_color = '#6b7db3' ) {

	$default_color = apply_filters( 'billow_theme_style_violet', $default_color );
	$color = billow_get_theme_mod_hex_color( 'billow_theme_style_violet', $default_color );

	return $color;
}

function billow_theme_dark_violet_color( $default_color = '#515f8a' ) {

	$default_color = apply_filters( 'billow_theme_style_dark_violet', $default_color );
	$color = billow_get_theme_mod_hex_color( 'billow_theme_style_dark_violet', $default_color );

	return $color;
}

// Theme Style Yellow
function billow_theme_yellow_color( $default_color = '#ffb617' ) {

	$default_color = apply_filters( 'billow_theme_style_yellow', $default_color );
	$color = billow_get_theme_mod_hex_color( 'billow_theme_style_yellow', $default_color );

	return $color;
}

function billow_theme_dark_yellow_color( $default_color = '#1d1d1d' ) {

	$default_color = apply_filters( 'billow_theme_style_dark_yellow', $default_color );
	$color = billow_get_theme_mod_hex_color( 'billow_theme_style_dark_yellow', $default_color );

	return $color;
}

function billow_echo_google_fonts_import( ){
	global $billow_google_font_options;

	$fonts = array();
	$subsets = array();
	foreach( $billow_google_font_options as $option_name ){
		$f = json_decode( get_theme_mod( $option_name, '' ));
		if( is_object( $f ) && !empty( $f->font ) ){
			if( !empty( $f->subset ) ){
				$subsets[$f->subset] = $f->subset;
			}

			if( !isset( $fonts[$f->font] ) ){
				$fonts[$f->font] = array();
			}

			foreach( array( 'regularweight','italicweight','boldweight' ) as $v ){
				if( !empty( $f->$v ) ){
					$fonts[$f->font][] = $f->$v;
				}
			}
		}
	}

	$families = array();
	if( count( $fonts ) > 0 ){
		foreach( $fonts as $font => $f ){
			$variants = array_unique( $f );
			$families[] = urlencode( $font ) . ':' . implode( ',', $variants );
		}

		if( is_ssl() ){
			$url = 'https://fonts.googleapis.com/css?family='.implode( '|',$families );
		} else{
			$url = 'http://fonts.googleapis.com/css?family='.implode( '|',$families );
		}

		if( count( $subsets ) > 0 ){
			$url.= '&subset=' . implode(',', array_unique( $subsets ) );
		}

		echo sprintf( "@import url('%s');\n", $url ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	}
}

$include_tags = isset( $include_tags ) ? $include_tags : true ;
if( $include_tags ):
	echo '<style type="text/css">'."\n";
endif;

billow_echo_google_fonts_import();
?>

/* Global */
body.billow,
.billow .site p,
.billow .site button,
.billow .site input,
.billow .site select,
.billow .site optgroup,
.billow .site textarea,
.billow .site span {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_base_color', '#404040' ) )?>;
}

.billow .site a,
.billow .site a:visited {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_link_color', '#f0932b' ) )?>;
}

.billow .site a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_link_hover_color', '#067690' ) )?>;
}

.billow h1,
.billow h2,
.billow h3,
.billow h4,
.billow h5,
.billow h6,
.billow .entry-title > a,
.billow span.title {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_heading_color', '#404040' ) )?>;
}

.billow .container {
	max-width: <?php echo sprintf( '%spx', billow_get_theme_mod_no_empty( 'billow_site_max_width', '1170' ) ) // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>;
	padding-left: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_site_padding', '2rem' ) )?>;
	padding-right: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_site_padding', '2rem' ) )?>;
}

.billow .site-content .container {
	padding-top: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_content_padding_top', '0rem' ) )?>;
	padding-bottom: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_content_padding_bottom', '0rem' ) )?>;
}

/* Header */
.billow:not(.home) header.site-header {
	background-image: url('<?php echo esc_html( billow_get_theme_mod_no_empty( 'header_image', '' ) )?>');
}

.billow #page header.site-header {
	margin-top: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_header_bar_margin_top', '0' ) )?>;
	margin-bottom: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_header_bar_margin_bottom', '0' ) )?>;
	padding-top: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_header_bar_padding_top', '0' ) )?>;
	padding-bottom: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_header_bar_padding_bottom', '0' ) )?>;
	border-bottom-width: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_header_border_bottom', '0px' ) )?>;
	border-bottom-style: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_header_border_bottom_style', 'solid' ) )?>;
	border-bottom-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_header_border_bottom_color', '' ) )?>;
}

.billow.header-boxshadow-on #page header.site-header {
	box-shadow: <?php echo sprintf( '%spx %spx %spx %s', billow_get_theme_mod_no_empty( 'billow_header_box_shadow_x', '0' ),billow_get_theme_mod_no_empty( 'billow_header_box_shadow_y', '2' ),billow_get_theme_mod_no_empty( 'billow_header_box_shadow_blur', '4' ),billow_get_theme_mod_no_empty( 'billow_header_box_shadow_color', 'rgba(0,0,0,.17)' ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>;
}

.billow:not(.home) header#masthead.site-header {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_header_bc_color', '#8ac6d1' ) )?>;
}

.billow header.site-header .header-wrap .container .main-info .site-branding .site-title {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'site_title_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'site_title_font_size', '1.8rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'site_title_font_line_height', 'normal' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'site_title_font_weight', '600' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'site_title_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'site_title_font_text_transform', 'none' ) )?>;
}

.billow header.site-header .header-wrap .container .main-info .site-branding p.site-description {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'title_tagline_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'title_tagline_font_size', '1rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'title_tagline_font_line_height', 'normal' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'title_tagline_font_weight', '500' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'title_tagline_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'title_tagline_font_text_transform', 'none' ) )?>;
}

.billow.theme-style-default header.site-header .header-wrap .container .main-info .site-branding .site-title a,
.billow.theme-style-default header.site-header .header-wrap .container .main-info .site-branding .site-description {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'header_textcolor', '#ffffff' ) )?>;
}

.billow .main-navigation ul > li > a {
	padding-left: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_menu_item_padding_left', '10px' ) )?>;
	padding-right: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_menu_item_padding_right', '10px' ) )?>;
}

.billow .main-navigation div > ul > li > a {
	height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_menu_height', '70px' ) )?>;
}

.billow header.site-header .header-wrap .container nav.main-navigation ul > li > a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_link_color', '#ffffff' ) )?>;
}

.billow header.site-header .header-wrap .container nav.main-navigation ul > li > a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_hover_link_color', '#ffffff' ) )?>;
}

.billow.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li.current-menu-item > a,
.billow.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li:hover > a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_hover_link_color', '#404040' ) )?>;
}

.billow .site-header .header-wrap .container .main-navigation ul.menu li ul li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_link_color', '#ffffff' ) )?>;
}

.billow .site-header .header-wrap .container .main-navigation ul.menu li ul li a:hover,
.billow .site-header .header-wrap .container .main-navigation ul.menu li ul li:hover > a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_hover_link_color', '#ffffff' ) )?>;
}

.billow .site-header .header-wrap .container .main-navigation ul.menu li ul li:hover > a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_hover_link_bc_color', '#77a2af' ) )?>;
}

.billow .site-header .header-wrap .container .main-navigation ul.menu li ul {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_bc_color', '#8ac6d1' ) )?>;
}

.billow .site-header .container .main-navigation:not(.toggled) ul.menu > li > a:before,
.billow .site-header .container .main-navigation:not(.toggled) ul.nav-menu > li > a:before {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_indicator_color', '#ffffff' ) )?>;
}

/* Front Page */
.billow.home .blw-hero-area .hero-content {
	justify-content: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_vertical_align', 'space-evenly' ) )?>;
	padding-top: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_layout_padding_top', '0' ) )?>;
	padding-right: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_layout_padding_right', '0' ) )?>;
	padding-bottom: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_layout_padding_bottom', '0' ) )?>;
	padding-left: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_layout_padding_left', '0' ) )?>;
}

.billow.home header.site-header {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_bar_bc', '#8ac6d1' ) )?>;
}

.billow.home.sticky-menu header.site-header.float-header {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_bar_bc', '#8ac6d1' ) )?>;
}

.billow.home .blw-hero-area .hero-bg {
	background-image: url('<?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_bc_image', '' ) )?>');
}

.billow.home .blw-hero-area .hero-bg::after {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_bc_overlay_color', '' ) )?>;
}

.billow.home .blw-hero-area .hero-content .hero-title .entry-title {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_title_font_color', '#ffffff' ) )?>;
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_title_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_title_font_size', '3.5rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_title_font_line_height', 'normal' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_title_font_weight', '600' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_title_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_title_font_text_transform', 'none' ) )?>;
	text-shadow: <?php echo sprintf( '%spx %spx %spx %s',
					billow_get_theme_mod_no_empty( 'billow_home_page_title_text_shadow_x', '0' ), // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					billow_get_theme_mod_no_empty( 'billow_home_page_title_text_shadow_y', '0' ), // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					billow_get_theme_mod_no_empty( 'billow_home_page_title_text_shadow_blur', '27' ), // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					billow_get_theme_mod_no_empty( 'billow_home_page_title_text_shadow_color', 'rgba(0, 0, 0, 0.37)' ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	?>;
}

.billow.home .hero-content a.button-slider {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_font_color', '#ffffff' ) )?>;
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_bc_color', '#8ac6d1' ) )?>;
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_font_size', '0.8rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_font_line_height', '1.5rem' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_font_weight', '700' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_font_text_transform', 'uppercase' ) )?>;
	box-shadow: <?php echo sprintf( '%spx %spx %spx %s',
					billow_get_theme_mod_no_empty( 'billow_home_page_button_box_shadow_x', '0' ), // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					billow_get_theme_mod_no_empty( 'billow_home_page_button_box_shadow_y', '0' ), // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					billow_get_theme_mod_no_empty( 'billow_home_page_button_box_shadow_blur', '27' ), // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					billow_get_theme_mod_no_empty( 'billow_home_page_button_box_shadow_color', 'rgba(0, 0, 0, 0.37)' ) ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	?>;
	border-width: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_border', '0px' ) )?>;
	border-style: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_border_style', 'solid' ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_border_color', '#8ac6d1' ) )?>;
	border-top-left-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_border_radius_top_left', '0.2rem' ) )?>;
	border-top-right-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_border_radius_top_right', '0.2rem' ) )?>;
	border-bottom-left-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_border_radius_bottom_left', '0.2rem' ) )?>;
	border-bottom-right-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_border_radius_bottom_right', '0.2rem' ) )?>;
}

.billow.home .hero-content a.button-slider:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_hover_font_color', '#ffffff' ) )?>;
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_hover_bc_color', '#8ac6d1' ) )?>;
	border-width: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_hover_border', '0px' ) )?>;
	border-style: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_hover_border_style', 'solid' ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_hover_border_color', '#8ac6d1' ) )?>;
	border-top-left-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_hover_border_radius_top_left', '0.2rem' ) )?>;
	border-top-right-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_hover_border_radius_top_right', '0.2rem' ) )?>;
	border-bottom-left-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_hover_border_radius_bottom_left', '0.2rem' ) )?>;
	border-bottom-right-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_button_hover_border_radius_bottom_right', '0.2rem' ) )?>;
}

/* Typography */
body.billow,
.billow p,
.billow button,
.billow input,
.billow select,
.billow optgroup,
.billow textarea {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_base_font', 'Open Sans' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_base_font_size', '1rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_base_font_line_height', '1.5' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_base_font_weight', '400' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_base_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_base_font_text_transform', 'none' ) )?>;
}

.billow h1 {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading1_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading1_font_size', '2.5rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading1_font_line_height', '3.25rem' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading1_font_weight', '400' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading1_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading1_font_text_transform', 'none' ) )?>;
}

.billow h2 {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading2_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading2_font_size', '1.688rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading2_font_line_height', '2.438rem' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading2_font_weight', '400' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading2_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading2_font_text_transform', 'none' ) )?>;
}

.billow h3 {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading3_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading3_font_size', '1.375rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading3_font_line_height', '1.625rem' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading3_font_weight', '400' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading3_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading3_font_text_transform', 'none' ) )?>;
}

.billow h4 {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading4_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading4_font_size', '1.188rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading4_font_line_height', '1.625rem' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading4_font_weight', '400' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading4_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading4_font_text_transform', 'none' ) )?>;
}

.billow h5 {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading5_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading5_font_size', '1rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading5_font_line_height', '1.625rem' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading5_font_weight', '400' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading5_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading5_font_text_transform', 'none' ) )?>;
}

.billow h5 {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading6_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading6_font_size', '1rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading6_font_line_height', '1.625rem' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading6_font_weight', '400' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading6_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_heading6_font_text_transform', 'none' ) )?>;
}

.billow .button:not(.customize-partial-edit-shortcut-button),
.billow input[type="button"],
.billow input[type="reset"],
.billow input[type="submit"],
.billow button[type="submit"],
.billow #page .woocommerce a.button,
.billow #page .woocommerce-info a.button,
.billow #page .woocommerce-info a.showcoupon,
.billow #page .woocommerce-message a.button,
.billow #page .woocommerce-message a.showcoupon,
.billow #page .woocommerce-error a.button,
.billow #page .woocommerce-error a.showcoupon,
.billow #page .single-product-wrapper a.button,
.billow #page .single-product-wrapper a.added_to_cart,
.billow #page .woocommerce-pagination ul.page-numbers li .current,
.billow #page .navigation.pagination .nav-links > *.current {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_font_size', '0.75rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_font_line_height', '1.5rem' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_font_weight', '700' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_font_text_transform', 'uppercase' ) )?>;
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_font_color', '#ffffff' ) )?>;
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', '#8ac6d1' ) )?>;
	border-width: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_border', '1px' ) )?>;
	border-style: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_border_style', 'solid' ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_border_color', '#8ac6d1' ) )?>;
	border-top-left-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_border_radius_top_left', '0.2rem' ) )?>;
	border-top-right-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_border_radius_top_right', '0.2rem' ) )?>;
	border-bottom-left-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_border_radius_bottom_left', '0.2rem' ) )?>;
	border-bottom-right-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_border_radius_bottom_right', '0.2rem' ) )?>;
}

.billow .button:not(.customize-partial-edit-shortcut-button):hover,
.billow input[type="button"]:hover,
.billow input[type="reset"]:hover,
.billow input[type="submit"]:hover,
.billow button[type="submit"]:hover,
.billow #page .woocommerce a.button:hover,
.billow #page .woocommerce-info a.button:hover,
.billow #page .woocommerce-info a.showcoupon:hover,
.billow #page .woocommerce-message a.button:hover,
.billow #page .woocommerce-message a.showcoupon:hover,
.billow #page .woocommerce-error a.button:hover,
.billow #page .woocommerce-error a.showcoupon:hover,
.billow #page .single-product-wrapper a.button:hover,
.billow #page .single-product-wrapper a.added_to_cart:hover,
.billow #page .woocommerce-pagination ul.page-numbers li .current:hover,
.billow #page .navigation.pagination .nav-links > *.current:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_font_color', '#ffffff' ) )?>;
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_bc_color', '#8ac6d1' ) )?>;
	border-width: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_hover_border', '1px' ) )?>;
	border-style: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_hover_border_style', 'solid' ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_border_color', '#8ac6d1' ) )?>;
	border-top-left-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_hover_border_radius_top_left', '0.2rem' ) )?>;
	border-top-right-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_hover_border_radius_top_right', '0.2rem' ) )?>;
	border-bottom-left-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_hover_border_radius_bottom_left', '0.2rem' ) )?>;
	border-bottom-right-radius: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_button_hover_border_radius_bottom_right', '0.2rem' ) )?>;
}

/* Blog */
body.billow header.post-entry-header .blw-overlay h1.entry-title {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_single_post_title_color', '#ffffff' ) )?>;
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_title_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_title_font_size', '3.4rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_title_font_line_height', 'normal' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_title_font_weight', '600' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_title_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_title_font_text_transform', 'initial' ) )?>;
}

body.billow header.post-entry-header .blw-overlay .entry-meta {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_single_post_meta_color', '#ffffff' ) )?>;
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_meta_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_meta_font_size', '0.9rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_meta_font_line_height', 'normal' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_meta_font_weight', '700' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_meta_font_letter_spacing', '0.1rem' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_meta_font_text_transform', 'uppercase' ) )?>;
}

body.billow header.post-entry-header .blw-overlay .entry-meta span.posted-on::before {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_single_post_date_icon_color', '#ffffff' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_date_icon_size', '1rem' ) )?>;
}

body.billow header.post-entry-header .blw-overlay .entry-meta span.author::before {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_single_post_author_icon_color', '#ffffff' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_author_icon_size', '1rem' ) )?>;
}

body.billow header.post-entry-header .blw-overlay .entry-meta span.tag-links::before {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_single_post_tag_icon_color', '#ffffff' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_tag_icon_size', '1rem' ) )?>;
}

body.billow header.post-entry-header .blw-overlay .entry-meta span.category::before {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_single_post_category_icon_color', '#ffffff' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_post_category_icon_size', '1rem' ) )?>;
}

.billow nav.navigation .nav-links {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_post_nav_bc', 'rgba(247, 247, 247, 1)' ) )?>;
	padding-top: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_padding_top', '1.8rem' ) )?>;
	padding-right: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_padding_right', '1.8rem' ) )?>;
	padding-bottom: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_padding_bottom', '1.8rem' ) )?>;
	padding-left: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_padding_left', '1.8rem' ) )?>;
}

.billow nav.navigation .nav-links div a {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_font_size', '1.1rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_font_line_height', 'normal' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_font_weight', '400' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_font_text_transform', 'capitalize' ) )?>;
}

.billow nav.navigation .nav-links div a .nav-title,
.billow nav.navigation .nav-links div .nav-icon {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_post_nav_color', '#f0932b' ) )?>;
}

.billow nav.navigation .nav-links div a:hover .nav-title,
.billow nav.navigation .nav-links div a:hover .nav-icon {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_post_nav_hover_color', '#21759b' ) )?>;
}

.billow.single-post .site-content .container {
	padding-top: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_content_padding_top', '' ) )?>;
	padding-bottom: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_single_content_padding_bottom', '' ) )?>;
}

/* Sidebar */
.billow .widget-area:not(.footer-widget-area) .widget .widget-title {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_sidebar_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_sidebar_font_size', '1.688rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_sidebar_font_line_height', '1.5rem' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_sidebar_font_weight', '400' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_sidebar_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_sidebar_font_text_transform', 'none' ) )?>;
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_sidebar_title_color', '#404040' ) )?>;
}

.billow .widget-area:not(.footer-widget-area) span,
.billow .widget-area:not(.footer-widget-area) ul li,
.billow .widget-area:not(.footer-widget-area) .widget_text .textwidget p,
.billow .widget-area:not(.footer-widget-area) .widget_calendar table.wp-calendar-table,
.billow .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content .post-meta a.date-link {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_sidebar_text_color', '#404040' ) )?>;
}

.billow .widget-area:not(.footer-widget-area) a,
.billow .widget-area:not(.footer-widget-area) .widget ul li a,
.billow .widget-area:not(.footer-widget-area) .widget_text .textwidget p a,
.billow .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title,
.billow .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_sidebar_link_color', '#f0932b' ) )?>;
}

.billow .widget-area:not(.footer-widget-area) a:hover,
.billow .widget-area:not(.footer-widget-area) .widget ul li a:hover,
.billow .widget-area:not(.footer-widget-area) .widget_text .textwidget p a:hover,
.billow .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title:hover,
.billow .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_sidebar_hover_link_color', '#067690' ) )?>;
}

.billow .shop-wrapper aside.widget-area,
.billow .main-wrap aside.widget-area {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_sidebar_bc_color', 'transparent' ) )?>;
}

/* Footer */
.billow footer.site-footer .footer-widget-area {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_footer_bc_color', '#77a2af' ) )?>;
	background-image: url('<?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_footer_bc_image', '' ) )?>');
}

.billow footer.site-footer .footer-widget-area ul.widget li.widget .widget-title {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_footer_widget_title_color', '#ffffff' ) )?>;
}

.billow footer.site-footer .footer-widget-area span,
.billow footer.site-footer .footer-widget-area figcaption,
.billow footer.site-footer .footer-widget-area .widget footer,
.billow footer.site-footer .footer-widget-area .widget p,
.billow footer.site-footer .footer-widget-area .widget cite,
.billow footer.site-footer .footer-widget-area .widget ul li,
.billow footer.site-footer .footer-widget-area .widget_text .textwidget p,
.billow footer.site-footer .footer-widget-area .widget_calendar table.wp-calendar-table,
.billow footer.site-footer .footer-widget-area .widget_calendar table.wp-calendar-table th,
.billow footer.site-footer .footer-widget-area .widget_calendar table.wp-calendar-table td,
.billow footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content .post-meta a.date-link,
.billow footer.site-footer .footer-widget-area .widget label {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_footer_widget_text_color', '#ffffff' ) )?>;
}

.billow footer.site-footer .footer-widget-area a,
.billow footer.site-footer .footer-widget-area .widget ul li a,
.billow footer.site-footer .footer-widget-area .widget_text .textwidget p a,
.billow footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content a.post-title,
.billow footer.site-footer .footer-widget-area .widget_calendar .wp-calendar-nav span a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_footer_widget_link_color', '#ffffff' ) )?>;
}

.billow footer.site-footer .footer-widget-area a:hover,
.billow footer.site-footer .footer-widget-area .widget ul li a:hover,
.billow footer.site-footer .footer-widget-area .widget_text .textwidget p a:hover,
.billow footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content a.post-title:hover,
.billow footer.site-footer .footer-widget-area .widget_calendar .wp-calendar-nav span a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_footer_widget_hover_link_color', '#b8ced5' ) )?>;
}

.billow footer.site-footer .site-info {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_copyright_bc_color', '#77a2af' ) )?>;
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_copyright_font_color', '#ffffff' ) )?>;
	padding-top: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_padding_top', '3rem' ) )?>;
	padding-right: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_padding_right', '0' ) )?>;
	padding-bottom: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_padding_bottom', '2rem' ) )?>;
	padding-left: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_padding_left', '0' ) )?>;
	border-top-width: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_border', '0px' ) )?>;
	border-top-style: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_border_style', 'solid' ) )?>;
	border-top-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_copyright_border_color', '' ) )?>;
}

.billow footer.site-footer .site-info .container {
	font-family: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_font', 'inherit' ) )?>;
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_font_size', '1rem' ) )?>;
	line-height: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_font_line_height', '1.5rem' ) )?>;
	font-weight: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_font_weight', '400' ) )?>;
	letter-spacing: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_font_letter_spacing', 'normal' ) )?>;
	text-transform: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_font_text_transform', 'none' ) )?>;
}

/* Social Networks */
.billow ul.social-networks li a i.fab {
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_social_links_size', '1.2rem' ) )?>;
}

.billow.blw-social-icon-custom ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', '' ) )?>;
}

.billow.blw-social-icon-custom ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', '' ) )?>;
}

.billow.blw-social-icon-custom .post-entry-header ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', '#ffffff' ) )?>;
}

.billow.blw-social-icon-custom .post-entry-header ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', '#ffffff' ) )?>;
}

.billow.blw-social-icon-custom.blw-social-icon-rounded ul.social-networks li a,
.billow.blw-social-icon-custom.blw-social-icon-square ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', '#77a2af' ) )?>;
}

.billow.blw-social-icon-custom.blw-social-icon-rounded ul.social-networks li a:hover,
.billow.blw-social-icon-custom.blw-social-icon-square ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', '#ffffff' ) )?>;
}

.billow.blw-social-icon-custom.blw-social-icon-rounded .post-entry-header ul.social-networks li a,
.billow.blw-social-icon-custom.blw-social-icon-square .post-entry-header ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', '#77a2af' ) )?>;
}

.billow.blw-social-icon-custom.blw-social-icon-rounded .post-entry-header ul.social-networks li a:hover,
.billow.blw-social-icon-custom.blw-social-icon-square .post-entry-header ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', '#ffffff' ) )?>;
}

.billow ul.social-networks li a {
	margin-top: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_social_links_spacing', '0.5rem' ) )?>;
	margin-left: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_social_links_spacing', '0.5rem' ) )?>;
	margin-right: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_social_links_spacing', '0.5rem' ) )?>;
}

.billow.blw-social-icon-rounded ul.social-networks li a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_rounded_bc_color', '#f7f7f7' ) )?>;
}

.billow.blw-social-icon-rounded ul.social-networks li a:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_rounded_bc_color', '#8ac6d1' ) )?>;
}

.billow.blw-social-icon-square ul.social-networks li a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_square_bc_color', '#f7f7f7' ) )?>;
}

.billow.blw-social-icon-square ul.social-networks li a:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_square_bc_color', '#8ac6d1' ) )?>;
}

.billow ul.social-networks li a span {
	<?php $billow_social_links_on_desktop = billow_get_theme_mod_no_empty( 'billow_social_links_on_desktop', 'none' )?>
	display: <?php echo '1' === $billow_social_links_on_desktop ? 'flex' : $billow_social_links_on_desktop // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>;
}

/* Scroll to Top */
.billow footer.site-footer #scroll-to-top span::before {
	font-size: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_copyright_font_size', '1.2rem' ) )?>;
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_icon_color', '#ffffff' ) )?>;
}

.billow footer.site-footer #scroll-to-top:hover span::before {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_icon_hover_color', '#ffffff' ) )?>;
}

.billow footer.site-footer #scroll-to-top {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_bc_color', 'rgba(195, 214, 219, 0.9)' ) )?>;
}

.billow footer.site-footer #scroll-to-top:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_bc_hover_color', 'rgba(195, 214, 219, 0.9)' ) )?>;
}

/* Theme Styles */
/* Green */
.billow.theme-style-green a,
.billow.theme-style-green a:visited,
.billow.theme-style-green #page .reply a.comment-reply-link {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_link_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_link_hover_color', '#333333' ) )?>;
}

.billow.theme-style-green header.site-header .header-wrap .container .main-info .site-branding .site-title a,
.billow.theme-style-green header.site-header .header-wrap .container .main-info .site-branding .site-description {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'header_textcolor', '#ffffff' ) )?>;
}

.billow.theme-style-green:not(.home) header#masthead.site-header {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_header_bc_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green #page .main-navigation ul.menu li ul li:hover > a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_hover_link_bc_color', '#333333' ) )?>;
}

.billow.theme-style-green #page .site-header .main-navigation ul.menu li ul {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_bc_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green.home header.site-header,
.billow.theme-style-green.home.sticky-menu header.site-header {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_bar_bc', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green.home .blw-hero-area .hero-bg {
	background-image: url(<?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_bc_image', '' ) )?>);
}

.billow.theme-style-green.home .blw-hero-area .hero-bg::after {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_bc_overlay_color', '' ) )?>;
}

.billow.theme-style-green.home .hero-content a.button-slider {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_bc_color', billow_theme_green_color() ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_border_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green.home .hero-content a.button-slider:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_hover_bc_color', '#333333' ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_hover_border_color', '#333333' ) )?>;
}

.billow.theme-style-green .button:not(.customize-partial-edit-shortcut-button),
.billow.theme-style-green input[type="button"],
.billow.theme-style-green input[type="reset"],
.billow.theme-style-green input[type="submit"],
.billow.theme-style-green button[type="submit"],
.billow.theme-style-green #page .woocommerce a.button,
.billow.theme-style-green #page .woocommerce-info a.button,
.billow.theme-style-green #page .woocommerce-info a.showcoupon,
.billow.theme-style-green #page .woocommerce-message a.button,
.billow.theme-style-green #page .woocommerce-message a.showcoupon,
.billow.theme-style-green #page .woocommerce-error a.button,
.billow.theme-style-green #page .woocommerce-error a.showcoupon,
.billow.theme-style-green #page .single-product-wrapper a.button,
.billow.theme-style-green #page .single-product-wrapper a.added_to_cart,
.billow.theme-style-green #page .woocommerce-pagination ul.page-numbers li .current,
.billow.theme-style-green #page .navigation.pagination .nav-links > *.current {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', billow_theme_green_color() ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_border_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green .button:not(.customize-partial-edit-shortcut-button):hover,
.billow.theme-style-green input[type="button"]:hover,
.billow.theme-style-green input[type="reset"]:hover,
.billow.theme-style-green input[type="submit"]:hover,
.billow.theme-style-green button[type="submit"]:hover,
.billow.theme-style-green #page .woocommerce a.button:hover,
.billow.theme-style-green #page .woocommerce-info a.button:hover,
.billow.theme-style-green #page .woocommerce-info a.showcoupon:hover,
.billow.theme-style-green #page .woocommerce-message a.button:hover,
.billow.theme-style-green #page .woocommerce-message a.showcoupon:hover,
.billow.theme-style-green #page .woocommerce-error a.button:hover,
.billow.theme-style-green #page .woocommerce-error a.showcoupon:hover,
.billow.theme-style-green #page .single-product-wrapper a.button:hover,
.billow.theme-style-green #page .single-product-wrapper a.added_to_cart:hover,
.billow.theme-style-green #page .woocommerce-pagination ul.page-numbers li .current:hover,
.billow.theme-style-green #page .navigation.pagination .nav-links > *.current:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_bc_color', '#333333' ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_border_color', '#333333' ) )?>;
}

.billow.theme-style-green #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active a,
.billow.theme-style-green #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li:hover a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active:hover a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_bc_color', '#333333' ) )?>;
}

.billow.theme-style-green form.search-form button.search-submit,
.billow.theme-style-green .widget_product_search .woocommerce-product-search button,
.billow.theme-style-green .mobile-menu-container.off a.close i {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green form.search-form button.search-submit:hover,
.billow.theme-style-green .widget_product_search .woocommerce-product-search button:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', '#333333' ) )?>;
}

.billow.theme-style-green .widget-area:not(.footer-widget-area) a,
.billow.theme-style-green .widget-area:not(.footer-widget-area) .widget ul li a,
.billow.theme-style-green .widget-area:not(.footer-widget-area) .widget_text .textwidget p a,
.billow.theme-style-green .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title,
.billow.theme-style-green .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_sidebar_link_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green .widget-area:not(.footer-widget-area) a:hover,
.billow.theme-style-green .widget-area:not(.footer-widget-area) .widget ul li a:hover,
.billow.theme-style-green .widget-area:not(.footer-widget-area) .widget_text .textwidget p a:hover,
.billow.theme-style-green .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title:hover,
.billow.theme-style-green .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_sidebar_hover_link_color', '#333333' ) )?>;
}

.billow.theme-style-green nav.navigation .nav-links div a .nav-title,
.billow.theme-style-green nav.navigation .nav-links div .nav-icon {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_post_nav_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green nav.navigation .nav-links div a:hover .nav-title,
.billow.theme-style-green nav.navigation .nav-links div a:hover .nav-icon {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_post_nav_hover_color', '#333333' ) )?>;
}

.billow.theme-style-green footer.site-footer .footer-widget-area a:hover,
.billow.theme-style-green footer.site-footer .footer-widget-area .widget ul li a:hover,
.billow.theme-style-green footer.site-footer .footer-widget-area .widget_text .textwidget p a:hover,
.billow.theme-style-green footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content a.post-title:hover,
.billow.theme-style-green footer.site-footer .footer-widget-area .widget_calendar .wp-calendar-nav span a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_footer_widget_hover_link_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green footer.site-footer .footer-widget-area {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_footer_bc_color', '#333333' ) )?>;
}

.billow.theme-style-green footer.site-footer .site-info {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_copyright_bc_color', '#333333' ) )?>;
}

.billow.theme-style-green.blw-social-icon-custom ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green.blw-social-icon-custom ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', '#333333' ) )?>;
}

.billow.theme-style-green.blw-social-icon-rounded ul.social-networks li a:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_rounded_bc_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green.blw-social-icon-square ul.social-networks li a:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_square_bc_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green.blw-social-icon-custom #page .post-entry-header ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', '#ffffff' ) )?>;
}

.billow.theme-style-green.blw-social-icon-custom #page .post-entry-header ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', '#333333' ) )?>;
}

.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-rounded #page .post-entry-header ul.social-networks li a,
.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-square #page .post-entry-header ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-rounded #page .post-entry-header ul.social-networks li a:hover,
.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-square #page .post-entry-header ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', '#333333' ) )?>;
}

.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a,
.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a:hover,
.billow.theme-style-green.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', '#333333' ) )?>;
}

.billow.theme-style-green.blw-social-icon-custom #page footer.site-footer ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', '#ffffff' ) )?>;
}

.billow.theme-style-green.blw-social-icon-custom #page footer.site-footer ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green footer.site-footer #scroll-to-top {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_bc_color', billow_theme_green_color() ) )?>;
}

.billow.theme-style-green footer.site-footer #scroll-to-top:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_bc_hover_color', '#333333' ) )?>;
}

/* Violet */
.billow.theme-style-violet a,
.billow.theme-style-violet a:visited,
.billow.theme-style-violet #page .reply a.comment-reply-link {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_link_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_link_hover_color', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet header.site-header .header-wrap .container .main-info .site-branding .site-title a,
.billow.theme-style-violet header.site-header .header-wrap .container .main-info .site-branding .site-description {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'header_textcolor', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet:not(.home) header#masthead.site-header {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_header_bc_color', billow_theme_lavender_color() ) )?>;
}

.billow.theme-style-violet header.site-header .header-wrap .container nav.main-navigation ul > li > a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_link_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet header.site-header .header-wrap .container nav.main-navigation ul > li > a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_hover_link_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li.current-menu-item > a,
.billow.theme-style-violet.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li:hover > a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_hover_link_color', '#ffffff' ) )?>;
}

.billow.theme-style-violet .site-header .header-wrap .container .main-navigation ul.menu li ul li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_link_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet .site-header .header-wrap .container .main-navigation ul.menu li ul li a:hover,
.billow.theme-style-violet .site-header .header-wrap .container .main-navigation ul.menu li ul li:hover > a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_hover_link_color', '#ffffff' ) )?>;
}

.billow.theme-style-violet #page .site-header .main-navigation ul.menu li ul li:hover > a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_hover_link_bc_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet #page .site-header .main-navigation ul.menu li ul {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_bc_color', billow_theme_lavender_color() ) )?>;
}

.billow.theme-style-violet .site-header .container .main-navigation:not(.toggled) ul.menu > li > a:before {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_indicator_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet.home header.site-header,
.billow.theme-style-violet.home header.site-header.fixed,
.billow.theme-style-violet.home.sticky-menu header.site-header {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_bar_bc', billow_theme_lavender_color() ) )?>;
}

.billow.theme-style-violet.home .blw-hero-area .hero-bg {
	background-image: url(<?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_bc_image', '' ) )?>);
}

.billow.theme-style-violet.home .blw-hero-area .hero-bg::after {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_bc_overlay_color', '' ) )?>;
}

.billow.theme-style-violet.home .hero-content a.button-slider {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_bc_color', billow_theme_violet_color() ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_border_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet.home .hero-content a.button-slider:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_hover_bc_color', billow_theme_dark_violet_color() ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_hover_border_color', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet .button:not(.customize-partial-edit-shortcut-button),
.billow.theme-style-violet input[type="button"],
.billow.theme-style-violet input[type="reset"],
.billow.theme-style-violet input[type="submit"],
.billow.theme-style-violet button[type="submit"],
.billow.theme-style-violet #page .woocommerce a.button,
.billow.theme-style-violet #page .woocommerce-info a.button,
.billow.theme-style-violet #page .woocommerce-info a.showcoupon,
.billow.theme-style-violet #page .woocommerce-message a.button,
.billow.theme-style-violet #page .woocommerce-message a.showcoupon,
.billow.theme-style-violet #page .woocommerce-error a.button,
.billow.theme-style-violet #page .woocommerce-error a.showcoupon,
.billow.theme-style-violet #page .single-product-wrapper a.button,
.billow.theme-style-violet #page .single-product-wrapper a.added_to_cart,
.billow.theme-style-violet #page .woocommerce-pagination ul.page-numbers li .current,
.billow.theme-style-violet #page .navigation.pagination .nav-links > *.current {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', billow_theme_violet_color() ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_border_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet .button:not(.customize-partial-edit-shortcut-button):hover,
.billow.theme-style-violet input[type="button"]:hover,
.billow.theme-style-violet input[type="reset"]:hover,
.billow.theme-style-violet input[type="submit"]:hover,
.billow.theme-style-violet button[type="submit"]:hover,
.billow.theme-style-violet #page .woocommerce a.button:hover,
.billow.theme-style-violet #page .woocommerce-info a.button:hover,
.billow.theme-style-violet #page .woocommerce-info a.showcoupon:hover,
.billow.theme-style-violet #page .woocommerce-message a.button:hover,
.billow.theme-style-violet #page .woocommerce-message a.showcoupon:hover,
.billow.theme-style-violet #page .woocommerce-error a.button:hover,
.billow.theme-style-violet #page .woocommerce-error a.showcoupon:hover,
.billow.theme-style-violet #page .single-product-wrapper a.button:hover,
.billow.theme-style-violet #page .single-product-wrapper a.added_to_cart:hover,
.billow.theme-style-violet #page .woocommerce-pagination ul.page-numbers li .current:hover,
.billow.theme-style-violet #page .navigation.pagination .nav-links > *.current:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_bc_color', billow_theme_dark_violet_color() ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_border_color', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active a,
.billow.theme-style-violet #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li:hover a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active:hover a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_bc_color', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet form.search-form button.search-submit,
.billow.theme-style-violet .widget_product_search .woocommerce-product-search button,
.billow.theme-style-violet header.site-header .header-wrap .container .main-navigation button.menu-toggle::before,
.billow.theme-style-violet .mobile-menu-container.off a.close i {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet form.search-form button.search-submit:hover,
.billow.theme-style-violet .widget_product_search .woocommerce-product-search button:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet .widget-area:not(.footer-widget-area) a,
.billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget ul li a,
.billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget_text .textwidget p a,
.billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title,
.billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_sidebar_link_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet .widget-area:not(.footer-widget-area) a:hover,
.billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget ul li a:hover,
.billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget_text .textwidget p a:hover,
.billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title:hover,
.billow.theme-style-violet .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_sidebar_hover_link_color', billow_theme_lavender_color() ) )?>;
}

.billow.theme-style-violet nav.navigation .nav-links div a .nav-title,
.billow.theme-style-violet nav.navigation .nav-links div .nav-icon {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_post_nav_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet nav.navigation .nav-links div a:hover .nav-title,
.billow.theme-style-violet nav.navigation .nav-links div a:hover .nav-icon {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_post_nav_hover_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet footer.site-footer .footer-widget-area a:hover,
.billow.theme-style-violet footer.site-footer .footer-widget-area .widget ul li a:hover,
.billow.theme-style-violet footer.site-footer .footer-widget-area .widget_text .textwidget p a:hover,
.billow.theme-style-violet footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content a.post-title:hover,
.billow.theme-style-violet footer.site-footer .footer-widget-area .widget_calendar .wp-calendar-nav span a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_footer_widget_hover_link_color', billow_theme_lavender_color() ) )?>;
}

.billow.theme-style-violet footer.site-footer .footer-widget-area {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_footer_bc_color', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet footer.site-footer .site-info {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_copyright_bc_color', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet.blw-social-icon-custom ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', '' ) )?>;
}

.billow.theme-style-violet.blw-social-icon-custom ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet.blw-social-icon-rounded.blw-social-icon-custom ul.social-networks li a,
.billow.theme-style-violet.blw-social-icon-square.blw-social-icon-custom ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet.blw-social-icon-rounded.blw-social-icon-custom ul.social-networks li a:hover,
.billow.theme-style-violet.blw-social-icon-square.blw-social-icon-custom ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', billow_theme_lavender_color() ) )?>;
}

.billow.theme-style-violet.blw-social-icon-rounded ul.social-networks li a:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_rounded_bc_color', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet.blw-social-icon-square ul.social-networks li a:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_square_bc_color', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet.blw-social-icon-custom #page footer.site-footer ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', billow_theme_lavender_color() ) )?>;
}

.billow.theme-style-violet.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a,
.billow.theme-style-violet.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', billow_theme_dark_violet_color() ) )?>;
}

.billow.theme-style-violet.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a:hover,
.billow.theme-style-violet.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', billow_theme_lavender_color() ) )?>;
}

.billow.theme-style-violet footer.site-footer #scroll-to-top {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_bc_color', billow_theme_violet_color() ) )?>;
}

.billow.theme-style-violet footer.site-footer #scroll-to-top:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_bc_hover_color', billow_theme_dark_violet_color() ) )?>;
}

/* Yellow */
.billow.theme-style-yellow a,
.billow.theme-style-yellow a:visited,
.billow.theme-style-yellow #page .reply a.comment-reply-link {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_link_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_link_hover_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow header.site-header .header-wrap .container .main-info .site-branding .site-title a,
.billow.theme-style-yellow header.site-header .header-wrap .container .main-info .site-branding .site-description {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'header_textcolor', '' ) )?>;
}

.billow.theme-style-yellow:not(.home) header#masthead.site-header {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_header_bc_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow header.site-header .header-wrap .container nav.main-navigation ul > li > a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_link_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow header.site-header .header-wrap .container nav.main-navigation ul > li > a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_hover_link_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow #page .main-navigation ul.menu li ul li:hover > a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_hover_link_bc_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow #page .site-header .main-navigation ul.menu li ul {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_bc_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow .site-header .container .main-navigation:not(.toggled) ul.menu > li > a:before {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_indicator_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow .site-header .header-wrap .container .main-navigation ul.menu li ul li a:hover,
.billow.theme-style-yellow .site-header .header-wrap .container .main-navigation ul.menu li ul li:hover > a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_dropdown_hover_link_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li.current-menu-item > a,
.billow.theme-style-yellow.menu-indicator-type-3 header.site-header .header-wrap .container nav.main-navigation ul > li:hover > a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_menu_hover_link_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow.home header.site-header,
.billow.theme-style-yellow.home header.site-header.fixed,
.billow.theme-style-yellow.home.sticky-menu header.site-header {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_bar_bc', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow.home .blw-hero-area .hero-bg {
	background-image: url(<?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_home_page_bc_image', '' ) )?>);
}

.billow.theme-style-yellow.home .blw-hero-area .hero-bg::after {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_bc_overlay_color', '' ) )?>;
}

.billow.theme-style-yellow.home .hero-content a.button-slider {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_bc_color', billow_theme_yellow_color() ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_border_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow.home .hero-content a.button-slider:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_hover_bc_color', billow_theme_dark_yellow_color() ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_home_page_button_hover_border_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow .button:not(.customize-partial-edit-shortcut-button),
.billow.theme-style-yellow input[type="button"],
.billow.theme-style-yellow input[type="reset"],
.billow.theme-style-yellow input[type="submit"],
.billow.theme-style-yellow button[type="submit"],
.billow.theme-style-yellow #page .woocommerce a.button,
.billow.theme-style-yellow #page .woocommerce-info a.button,
.billow.theme-style-yellow #page .woocommerce-info a.showcoupon,
.billow.theme-style-yellow #page .woocommerce-message a.button,
.billow.theme-style-yellow #page .woocommerce-message a.showcoupon,
.billow.theme-style-yellow #page .woocommerce-error a.button,
.billow.theme-style-yellow #page .woocommerce-error a.showcoupon,
.billow.theme-style-yellow #page .single-product-wrapper a.button,
.billow.theme-style-yellow #page .single-product-wrapper a.added_to_cart,
.billow.theme-style-yellow #page .woocommerce-pagination ul.page-numbers li .current,
.billow.theme-style-yellow #page .navigation.pagination .nav-links > *.current {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', billow_theme_yellow_color() ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_border_color', billow_theme_yellow_color() ) )?>;
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_font_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow .button:not(.customize-partial-edit-shortcut-button):hover,
.billow.theme-style-yellow input[type="button"]:hover,
.billow.theme-style-yellow input[type="reset"]:hover,
.billow.theme-style-yellow input[type="submit"]:hover,
.billow.theme-style-yellow button[type="submit"]:hover,
.billow.theme-style-yellow #page .woocommerce a.button:hover,
.billow.theme-style-yellow #page .woocommerce-info a.button:hover,
.billow.theme-style-yellow #page .woocommerce-info a.showcoupon:hover,
.billow.theme-style-yellow #page .woocommerce-message a.button:hover,
.billow.theme-style-yellow #page .woocommerce-message a.showcoupon:hover,
.billow.theme-style-yellow #page .woocommerce-error a.button:hover,
.billow.theme-style-yellow #page .woocommerce-error a.showcoupon:hover,
.billow.theme-style-yellow #page .single-product-wrapper a.button:hover,
.billow.theme-style-yellow #page .single-product-wrapper a.added_to_cart:hover,
.billow.theme-style-yellow #page .woocommerce-pagination ul.page-numbers li .current:hover,
.billow.theme-style-yellow #page .navigation.pagination .nav-links > *.current:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_bc_color', billow_theme_dark_yellow_color() ) )?>;
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_border_color', billow_theme_dark_yellow_color() ) )?>;
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_font_color', '#ffffff' ) )?>;
}

.billow.theme-style-yellow #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active a,
.billow.theme-style-yellow #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li:hover a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', billow_theme_yellow_color() ) )?>;
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_font_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow #page .woocommerce .blw-MyAccount .woocommerce-MyAccount-navigation ul li.is-active:hover a {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_bc_color', billow_theme_dark_yellow_color() ) )?>;
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_font_color', '#ffffff' ) )?>;
}

.billow.theme-style-yellow form.search-form button.search-submit,
.billow.theme-style-yellow .widget_product_search .woocommerce-product-search button,
.billow.theme-style-yellow header.site-header .header-wrap .container .main-navigation button.menu-toggle::before,
.billow.theme-style-yellow .mobile-menu-container.off a.close i {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow form.search-form button.search-submit:hover,
.billow.theme-style-yellow .widget_product_search .woocommerce-product-search button:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_bc_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow.error404 section.error-404 .first-section .search-content a.backhome:hover {
	border-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_border_color', billow_theme_yellow_color() ) )?>;
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_button_hover_font_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow .widget-area:not(.footer-widget-area) a,
.billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget ul li a,
.billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget_text .textwidget p a,
.billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title,
.billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_sidebar_link_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow .widget-area:not(.footer-widget-area) a:hover,
.billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget ul li a:hover,
.billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget_text .textwidget p a:hover,
.billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget-latest-posts ul li.widget-holder .content a.post-title:hover,
.billow.theme-style-yellow .widget-area:not(.footer-widget-area) .widget_calendar .wp-calendar-nav span a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_sidebar_hover_link_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow nav.navigation .nav-links div a .nav-title,
.billow.theme-style-yellow nav.navigation .nav-links div .nav-icon {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_post_nav_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow nav.navigation .nav-links div a:hover .nav-title,
.billow.theme-style-yellow nav.navigation .nav-links div a:hover .nav-icon {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_post_nav_hover_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow footer.site-footer .footer-widget-area a:hover,
.billow.theme-style-yellow footer.site-footer .footer-widget-area .widget ul li a:hover,
.billow.theme-style-yellow footer.site-footer .footer-widget-area .widget_text .textwidget p a:hover,
.billow.theme-style-yellow footer.site-footer .footer-widget-area .widget-latest-posts ul li.widget-holder .content a.post-title:hover,
.billow.theme-style-yellow footer.site-footer .footer-widget-area .widget_calendar .wp-calendar-nav span a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_footer_widget_hover_link_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow footer.site-footer .footer-widget-area {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_footer_bc_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow footer.site-footer .site-info {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_copyright_bc_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow.blw-social-icon-custom ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow.blw-social-icon-custom ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow.blw-social-icon-rounded.blw-social-icon-custom ul.social-networks li a,
.billow.theme-style-yellow.blw-social-icon-square.blw-social-icon-custom ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow.blw-social-icon-rounded.blw-social-icon-custom ul.social-networks li a:hover,
.billow.theme-style-yellow.blw-social-icon-square.blw-social-icon-custom ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow.blw-social-icon-rounded ul.social-networks li a:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_rounded_bc_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow.blw-social-icon-square ul.social-networks li a:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_square_bc_color', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow.blw-social-icon-custom #page footer.site-footer ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', '#ffffff' ) )?>;
}

.billow.theme-style-yellow.blw-social-icon-custom #page footer.site-footer ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a,
.billow.theme-style-yellow.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_color_custom', billow_theme_dark_yellow_color() ) )?>;
}

.billow.theme-style-yellow.blw-social-icon-custom.blw-social-icon-rounded #page footer.site-footer ul.social-networks li a:hover,
.billow.theme-style-yellow.blw-social-icon-custom.blw-social-icon-square #page footer.site-footer ul.social-networks li a:hover {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_social_links_hover_color_custom', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow footer.site-footer #scroll-to-top {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_bc_color', billow_theme_yellow_color() ) )?>;
}

.billow.theme-style-yellow footer.site-footer #scroll-to-top span::before {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_icon_color', '#1d1d1d' ) )?>;
}

.billow.theme-style-yellow footer.site-footer #scroll-to-top:hover span::before {
	color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_icon_color', '#ffffff' ) )?>;
}

.billow.theme-style-yellow footer.site-footer #scroll-to-top:hover {
	background-color: <?php echo esc_html( billow_get_theme_mod_hex_color( 'billow_scroll_top_bc_hover_color', billow_theme_dark_yellow_color() ) )?>;
}

/* Responsive Media Queries */
@media only screen and ( max-width: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_media', '48rem' ) )?> ) {
	.billow ul.social-networks li a span {
		<?php $billow_social_links_on_tablet = billow_get_theme_mod_no_empty( 'billow_social_links_on_tablet', 'none' )?>
		display: <?php echo '1' === $billow_social_links_on_tablet ? 'flex' : $billow_social_links_on_tablet // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>;
	}
}

@media only screen and ( max-width: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_media', '35rem' ) )?> ) {
	.billow header.site-header .header-wrap .container .main-info .site-branding .site-title {
		font-size: 2rem;
	}

	.billow nav.navigation .nav-links {
		padding-top: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_padding_top', '1rem' ) )?>;
		padding-right: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_padding_right', '1rem' ) )?>;
		padding-bottom: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_padding_bottom', '1rem' ) )?>;
		padding-left: <?php echo esc_html( billow_get_theme_mod_no_empty( 'billow_post_nav_padding_left', '1rem' ) )?>;
	}

	.billow ul.social-networks li a span {
		<?php $billow_social_links_on_mobile = billow_get_theme_mod_no_empty( 'billow_social_links_on_mobile', 'none' )?>
		display: <?php echo '1' === $billow_social_links_on_mobile ? 'flex' : $billow_social_links_on_mobile // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>;
	}
}

<?php

if( $include_tags ):
	echo '</style>';
endif;
