<?php
/**
 * My Addresses
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/myaccount/my-address.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 2.6.0
 */

defined( 'ABSPATH' ) || exit;

$customer_id = get_current_user_id(); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound

if ( ! wc_ship_to_billing_address_only() && wc_shipping_enabled() ) {
	$get_addresses = apply_filters( // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
		'woocommerce_my_account_get_addresses', // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
		array(
			'billing'  => __( 'Billing address', 'billow' ),
			'shipping' => __( 'Shipping address', 'billow' ),
		),
		$customer_id
	);
} else {
	$get_addresses = apply_filters( // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
		'woocommerce_my_account_get_addresses', // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
		array(
			'billing' => __( 'Billing address', 'billow' ),
		),
		$customer_id
	);
}

$oldcol = 1; // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
$col    = 1; // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
?>

<div class="MyAccount-content--address">

	<div class="wc-MyAccount-sub-heading">
		<h2><?php esc_html( 'Addresses', 'billow' ); ?></h2>
		<p>
			<?php echo apply_filters( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					'woocommerce_my_account_my_address_description', // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedHooknameFound
					esc_html__( 'The following addresses will be used on the checkout page by default.', 'billow' ) // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				); ?>
		</p>
	</div>

	<div class="wc-MyAccount-inner-content">
		<?php if ( ! wc_ship_to_billing_address_only() && wc_shipping_enabled() ) : ?>
			<div class="u-columns woocommerce-Addresses col2-set addresses">
		<?php endif; ?>

		<?php foreach ( $get_addresses
			as $name // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
			=>
			$title ) : // phpcs:ignore WordPress.WP.GlobalVariablesOverride.Prohibited ?>

			<?php
			$address = wc_get_account_formatted_address( $name ); // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
			$col     = $col * -1; // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
			$oldcol  = $oldcol * -1; // phpcs:ignore WPThemeReview.CoreFunctionality.PrefixAllGlobals.NonPrefixedVariableFound
			?>

			<div class="u-column<?php echo $col < 0 ? 1 : 2; ?> col-<?php echo $oldcol < 0 ? 1 : 2; ?> woocommerce-Address">
				<header class="woocommerce-Address-title title">
					<h3><?php echo esc_html( $title ); ?></h3>
				</header>
				<address><?php
					echo $address ? wp_kses_post( $address ) : esc_html_e( 'You have not set up this type of address yet.', 'billow' );
				?></address>
				<a href="<?php echo esc_url( wc_get_endpoint_url( 'edit-address', $name ) ); ?>" class="edit"><?php echo $address ? esc_html__( 'Edit', 'billow' ) : esc_html__( 'Add', 'billow' ); ?></a>
			</div>

		<?php endforeach; ?>

		<?php if ( ! wc_ship_to_billing_address_only() && wc_shipping_enabled() ) : ?>
			</div>
		<?php endif; ?>
	</div>

</div>
